"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _tape = require("tape");

var _tape2 = _interopRequireDefault(_tape);

var _valueIndexOf = require("../valueIndexOf");

var _valueIndexOf2 = _interopRequireDefault(_valueIndexOf);

(0, _tape2["default"])("default options", function (t) {
  t.deepEqual(valueIndexOfResults({
    value: "abc cba",
    char: "c" }), [2, 4]);
  t.deepEqual(valueIndexOfResults({
    value: "abc cb",
    char: "a" }), [0]);
  t.deepEqual(valueIndexOfResults({
    value: "abc cba",
    char: "b" }), [1, 5]);
  t.end();
});

(0, _tape2["default"])("`onlyOne` option", function (t) {
  t.deepEqual(valueIndexOfResults({
    value: "abc cba",
    char: "c",
    onlyOne: true }), [2]);
  t.deepEqual(valueIndexOfResults({
    value: "abc cba",
    char: "a",
    onlyOne: true }), [0]);
  t.deepEqual(valueIndexOfResults({
    value: "abc cba",
    char: "b",
    onlyOne: false }), [1, 5]);
  t.end();
});

(0, _tape2["default"])("`insideFunction` option", function (t) {
  t.deepEqual(valueIndexOfResults({
    value: "abc var(--cba)",
    char: "c",
    insideFunction: true }), [10]);
  t.deepEqual(valueIndexOfResults({
    value: "abc var(--cba)",
    char: "a",
    insideFunction: true }), [12]);
  t.deepEqual(valueIndexOfResults({
    value: "abc \"var(--cba)\"",
    char: "a",
    insideFunction: true }), []);
  t.deepEqual(valueIndexOfResults({
    value: "translate(1px, calc(1px * 2))",
    char: "1",
    insideFunction: true }), [10, 20]);
  t.deepEqual(valueIndexOfResults({
    value: "abc \"var(--cba)\"",
    char: "a",
    insideFunction: false }), [0]);
  t.deepEqual(valueIndexOfResults({
    value: "var(--horse)",
    char: "v",
    insideFunction: true }), []);
  t.end();
});

(0, _tape2["default"])("`outsideFunction` option", function (t) {
  t.deepEqual(valueIndexOfResults({
    value: "abc var(--cba)",
    char: "c",
    outsideFunction: true }), [2]);
  t.deepEqual(valueIndexOfResults({
    value: "abc var(--cba)",
    char: "a",
    outsideFunction: true }), [0]);
  t.deepEqual(valueIndexOfResults({
    value: "abc \"a var(--cba)\"",
    char: "a",
    outsideFunction: true }), [0]);
  t.deepEqual(valueIndexOfResults({
    value: "translate(1px, calc(1px * 2))",
    char: "1",
    outsideFunction: true }), []);
  t.deepEqual(valueIndexOfResults({
    value: "var(--horse)",
    char: "v",
    outsideFunction: true }), []);
  t.end();
});

(0, _tape2["default"])("ignores matches within single-quote strings", function (t) {
  t.deepEqual(valueIndexOfResults({
    value: "abc 'abc'",
    char: "c" }), [2]);
  t.deepEqual(valueIndexOfResults({
    value: "abc 'abc' cba",
    char: "c" }), [2, 10]);
  t.end();
});

(0, _tape2["default"])("ignores matches within double-quote strings", function (t) {
  /* eslint-disable quotes */
  t.deepEqual(valueIndexOfResults({
    value: "abc \"abc\"",
    char: "c" }), [2]);
  t.deepEqual(valueIndexOfResults({
    value: "abc \"abc\" cba",
    char: "c" }), [2, 10]);
  t.end();
});

(0, _tape2["default"])("handles escaped double-quotes in double-quote strings", function (t) {
  /* eslint-disable quotes */
  t.deepEqual(valueIndexOfResults({
    value: "abc \"ab\\\"c\"",
    char: "c" }), [2]);
  t.deepEqual(valueIndexOfResults({
    value: "abc \"a\\\"bc\" foo cba",
    char: "c" }), [2, 16]);
  t.end();
});

(0, _tape2["default"])("handles escaped double-quotes in single-quote strings", function (t) {
  t.deepEqual(valueIndexOfResults({
    value: "abc 'ab\\'c'",
    char: "c" }), [2]);
  t.deepEqual(valueIndexOfResults({
    value: "abc 'a\\'bc' foo cba",
    char: "c" }), [2, 16]);
  t.end();
});

(0, _tape2["default"])("count", function (t) {
  var endCounts = [];
  (0, _valueIndexOf2["default"])({ value: "123 123 123", char: "1" }, function (index, count) {
    endCounts.push(count);
  });
  t.deepEqual(endCounts, [1, 2, 3]);
  t.end();
});

function valueIndexOfResults(options) {
  var results = [];
  (0, _valueIndexOf2["default"])(options, function (i) {
    return results.push(i);
  });
  return results;
}
/* eslint-enable quotes */
/* eslint-enable quotes */